@@ -61,9 +61,6 @@ typedef struct _CdCache {
   char *disc_udi;
 #endif
 
-  /* capabilities of the device */
-  int cap;
-
   /* Whether we have a medium */
   guint has_medium : 1;
   /* if we're checking a media, or a dir */
@@ -473,25 +470,9 @@ cd_cache_open_mountpoint (CdCache *cache,
   return TRUE;
 }
 
-static void
-cb_umount_done (gboolean success, char * error,
-                char * detail, gboolean * called)
-{
-  *called = TRUE;
-}
-
 static void
 cd_cache_free (CdCache *cache)
 {
-  /* umount if we mounted */
-  if (cache->self_mounted && cache->mounted) {
-    gboolean called = FALSE;
-
-    gnome_vfs_drive_unmount (cache->drive,
-	(GnomeVFSVolumeOpCallback) cb_umount_done, &called);
-    while (!called) g_main_context_iteration (NULL, TRUE);
-  }
-
 #ifdef HAVE_HAL
   if (cache->ctx != NULL) {
     DBusConnection *conn;
@@ -829,7 +810,8 @@ totem_cd_detect_type_with_url (const char *device,
     *url = totem_cd_mrl_from_type ("vcd", device);
     break;
   case MEDIA_TYPE_CDDA:
-    *url = totem_cd_mrl_from_type ("cdda", device);
+    *url = totem_cd_mrl_from_type ("cdda", cache->device ?
+				   cache->device : device);
     break;
   case MEDIA_TYPE_DATA:
     *url = g_strdup (cache->mountpoint);
@@ -851,7 +833,7 @@ totem_cd_detect_type (const char  *device,
 }
 
 gboolean
-totem_cd_has_medium (const char  *device)
+totem_cd_has_medium (const char *device)
 {
   CdCache *cache;
   gboolean retval = TRUE;
@@ -876,6 +858,8 @@ totem_cd_get_human_readable_name (TotemDiscMediaType type)
     return N_("Video CD");
   case MEDIA_TYPE_DVD:
     return N_("DVD");
+  case MEDIA_TYPE_DVB:
+    return N_("Digital Television");
   default:
     g_assert_not_reached ();
   }
