@@ -375,38 +375,6 @@ my_gnome_vfs_get_mime_type_with_data (const char *uri, gpointer *data, TotemPlPa
 	return g_strdup (mimetype);
 }
 
-xmlDocPtr
-totem_pl_parser_parse_xml_file (const char *url)
-{
-	xmlDocPtr doc;
-	char *contents;
-	int size;
-
-	if (gnome_vfs_read_entire_file (url, &size, &contents) != GNOME_VFS_OK)
-		return NULL;
-
-	/* Try to remove HTML style comments */
-	{
-		char *needle;
-
-		while ((needle = strstr (contents, "<!--")) != NULL) {
-			while (strncmp (needle, "-->", 3) != 0) {
-				*needle = ' ';
-				needle++;
-				if (*needle == '\0')
-					break;
-			}
-		}
-	}
-
-	doc = xmlParseMemory (contents, size);
-	if (doc == NULL)
-		doc = xmlRecoverMemory (contents, size);
-	g_free (contents);
-
-	return doc;
-}
-
 char *
 totem_pl_parser_base_url (const char *url)
 {
@@ -450,11 +418,18 @@ totem_pl_parser_line_is_empty (const char *line)
 gboolean
 totem_pl_parser_write_string (GnomeVFSHandle *handle, const char *buf, GError **error)
 {
-	GnomeVFSResult res;
-	GnomeVFSFileSize written;
 	guint len;
 
 	len = strlen (buf);
+	return totem_pl_parser_write_buffer (handle, buf, len, error);
+}
+
+gboolean
+totem_pl_parser_write_buffer (GnomeVFSHandle *handle, const char *buf, guint len, GError **error)
+{
+	GnomeVFSResult res;
+	GnomeVFSFileSize written;
+
 	res = gnome_vfs_write (handle, buf, len, &written);
 	if (res != GNOME_VFS_OK || written < len) {
 		g_set_error (error,
@@ -560,6 +535,9 @@ totem_pl_parser_write_with_title (TotemPlParser *parser, GtkTreeModel *model,
 	case TOTEM_PL_PARSER_XSPF:
 		return totem_pl_parser_write_xspf (parser, model, func,
 				output, title, user_data, error);
+	case TOTEM_PL_PARSER_IRIVER_PLA:
+		return totem_pl_parser_write_pla (parser, model, func,
+				output, title, user_data, error);
 	default:
 		g_assert_not_reached ();
 	}
@@ -717,6 +695,10 @@ totem_pl_parser_init (TotemPlParser *parser)
 				     "String representing the default UI mode (only compact is supported)", NULL,
 				     G_PARAM_READABLE & G_PARAM_WRITABLE);
 	g_param_spec_pool_insert (parser->priv->pspec_pool, pspec, TOTEM_TYPE_PL_PARSER);
+	pspec = g_param_spec_string ("endtime", "endtime",
+				     "String representing the end time of the stream", NULL,
+				     G_PARAM_READABLE & G_PARAM_WRITABLE);
+	g_param_spec_pool_insert (parser->priv->pspec_pool, pspec, TOTEM_TYPE_PL_PARSER);
 }
 
 static void
@@ -745,10 +727,10 @@ totem_pl_parser_add_url_valist (TotemPlParser *parser,
 				va_list      var_args)
 {
 	const char *name;
-	char *title, *url, *genre, *base;
+	char *title, *url;
 	GHashTable *metadata;
 
-	title = url = genre = base = NULL;
+	title = url = NULL;
 
 	g_object_ref (G_OBJECT (parser));
 	metadata = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
@@ -785,10 +767,21 @@ totem_pl_parser_add_url_valist (TotemPlParser *parser,
 		/* Ignore empty values */
 		string = g_value_get_string (&value);
 		if (string != NULL && string[0] != '\0') {
+			char *fixed = NULL;
+
+			if (g_utf8_validate (string, -1, NULL) == FALSE) {
+				fixed = g_convert (string, -1, "UTF-8", "ISO8859-1", NULL, NULL, NULL);
+				if (fixed == NULL) {
+					g_value_unset (&value);
+					name = va_arg (var_args, char*);
+					continue;
+				}
+			}
+
 			/* Add other values to the metadata hashtable */
 			g_hash_table_insert (metadata,
 					     g_strdup (name),
-					     g_value_dup_string (&value));
+					     g_strdup (fixed ? fixed : string));
 		}
 
 		g_value_unset (&value);
@@ -831,11 +824,28 @@ totem_pl_parser_add_one_url (TotemPlParser *parser, const char *url, const char
 				 NULL);
 }
 
+static char *
+totem_pl_parser_remove_filename (const char *url)
+{
+	char *no_frag, *no_file, *no_qmark, *qmark;
+
+	no_frag = gnome_vfs_make_uri_canonical_strip_fragment (url);
+	qmark = strrchr (no_frag, '?');
+	if (qmark == NULL)
+		return no_frag;
+	no_qmark = g_strndup (no_frag, qmark - no_frag);
+	no_file = totem_pl_parser_base_url (no_qmark);
+	g_free (no_qmark);
+	g_free (no_frag);
+
+	return no_file;
+}
+
 char *
 totem_pl_resolve_url (const char *base, const char *url)
 {
 	GnomeVFSURI *base_uri, *new;
-	char *resolved;
+	char *resolved, *base_no_frag;
 
 	g_return_val_if_fail (url != NULL, NULL);
 	g_return_val_if_fail (base != NULL, g_strdup (url));
@@ -844,15 +854,19 @@ totem_pl_resolve_url (const char *base, const char *url)
 	if (strstr (url, "://") != NULL)
 		return g_strdup (url);
 
+	/* Strip fragment and filename */
+	base_no_frag = totem_pl_parser_remove_filename (base);
+
 	/* gnome_vfs_uri_append_path is trying to be clever and
 	 * merges paths that look like they're the same */
 	if (url[0] != '/') {
-		char *newbase = g_strdup_printf ("%s/", base);
+		char *newbase = g_strdup_printf ("%s/", base_no_frag);
 		base_uri = gnome_vfs_uri_new (newbase);
 		g_free (newbase);
 	} else {
-		base_uri = gnome_vfs_uri_new (base);
+		base_uri = gnome_vfs_uri_new (base_no_frag);
 	}
+	g_free (base_no_frag);
 
 	g_return_val_if_fail (base_uri != NULL, g_strdup (url));
 
@@ -1032,7 +1046,7 @@ totem_pl_parser_parse_internal (TotemPlParser *parser, const char *url,
 	char *mimetype;
 	guint i;
 	gpointer data = NULL;
-	TotemPlParserResult ret = TOTEM_PL_PARSER_RESULT_ERROR;
+	TotemPlParserResult ret = TOTEM_PL_PARSER_RESULT_UNHANDLED;
 	gboolean found = FALSE;
 
 	if (parser->priv->recurse_level > RECURSE_LEVEL_MAX)
@@ -1232,6 +1246,8 @@ totem_pl_parser_can_parse_from_data (const char *data,
 		}
 	}
 
+	D(g_message ("Is unsupported mime-type '%s'", mimetype));
+
 	return FALSE;
 }
 
